#[non_exhaustive]pub struct CapabilityCheckLayer {}Expand description
CapabilityCheckLayer validates optional operation arguments against service capabilities.
Similar to CorrectnessChecker, this layer verifies selected optional arguments for write,
copy, and list operations against the capabilities of the underlying service. If an argument is
not supported, an error is returned directly.
Notes
There are two main differences between this checker with the CorrectnessChecker:
-
This checker provides additional checks for capabilities like write_with_content_type and list_with_versions, among others. These capabilities do not affect data integrity, even if the underlying storage services do not support them.
-
OpenDAL doesn’t apply this checker by default. Users can enable this layer if they want to enforce stricter requirements.
Examples
let _ = Operator::new(services::Memory::default())?
.layer(CapabilityCheckLayer::new());Implementations
Sourceimpl CapabilityCheckLayer
impl CapabilityCheckLayer
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new CapabilityCheckLayer.